open Core.Std

type expression =
  | Var of string
  | IntLit of int
  | BoolLit of bool
  | Neg of expression
  | Not of expression
  | Plus of expression * expression
  | Minus of expression * expression
  | Times of expression * expression
  | Divide of expression * expression
  | LT of expression * expression
  | GT of expression * expression
  | Equal of expression * expression
  | And of expression * expression
  | Or of expression * expression

type statement =
  | Assign of string * expression
  | If of expression * statement * statement
  | While of expression * statement
  | Block of statement list
  | Print of expression
  | Empty

type value = IntVal of int | BoolVal of bool

val parse_expr   : string -> expression option
val parse_string : string -> statement option
val parse_file   : string -> statement option
